@@ -8,11 +8,10 @@ Struct = dict
 Float = float
 Int = int
 Boolean = bool
-from gaia_sdk.graphql.request.enumeration.RuntimeState import RuntimeState
-from gaia_sdk.graphql.request.enumeration.SkillState import SkillState
 from gaia_sdk.graphql.request.enumeration.Order import Order
 from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
 from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeType import EdgeType
 
 class Tenant:
     """
@@ -43,15 +42,3 @@ class Tenant:
     @property
     def qualifier(self) -> String:
         return String(self.dictionary.get("qualifier"))
-    """
-    The list of implicit identities
-    """
-    @property
-    def implicit_identities(self) -> List[String]:
-        return list(map(lambda x: String(x), self.dictionary.get("implicitIdentities")))
-    """
-    The list of explicit identities
-    """
-    @property
-    def explicit_identities(self) -> List[String]:
-        return list(map(lambda x: String(x), self.dictionary.get("explicitIdentities")))
